@@ -42,14 +42,15 @@ class AsyncSandboxOpts(TypedDict):
     envd_version: Optional[str]
     envd_access_token: Optional[str]
     connection_config: ConnectionConfig
-    ssh_host: str
-    ssh_port: int
-    ssh_username: str
-    ssh_password: str
-    adb_auth_command: str
-    adb_auth_password: str
-    adb_connect_command: str
-    adb_forwarder_command: str
+    # optional field
+    ssh_host: Optional[str]
+    ssh_port: Optional[int]
+    ssh_username: Optional[str]
+    ssh_password: Optional[str]
+    adb_auth_command: Optional[str]
+    adb_auth_password: Optional[str]
+    adb_connect_command: Optional[str]
+    adb_forwarder_command: Optional[str]
 
 
 class AsyncSandbox(SandboxSetup, SandboxApi):
@@ -131,6 +132,13 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
         """Private setter for envd token"""
         self.__envd_access_token = value
 
+    # @property
+    # def envd_version(self) -> str:
+    #     return self._envd_version
+    # @envd_version.setter
+    # def envd_version(self, value: str):
+    #     self._envd_version = value
+
     @property
     def connection_config(self) -> ConnectionConfig:
         return self._connection_config
@@ -143,18 +151,19 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
 
         self._sandbox_id = opts["sandbox_id"]
         self._connection_config = opts["connection_config"]
-        self._ssh_host = opts["ssh_host"]
-        self._ssh_port = opts["ssh_port"]
-        self._ssh_username = opts["ssh_username"]
-        self._ssh_password = opts["ssh_password"]
-        self._adb_auth_command = opts["adb_auth_command"]
-        self._adb_auth_password = opts["adb_auth_password"]
-        self._adb_connect_command = opts["adb_connect_command"]
-        self._adb_forwarder_command = opts["adb_forwarder_command"]
+        # Optional fields
+        self._ssh_host = opts.get("ssh_host")
+        self._ssh_port = opts.get("ssh_port")
+        self._ssh_username = opts.get("ssh_username")
+        self._ssh_password = opts.get("ssh_password")
+        self._adb_auth_command = opts.get("adb_auth_command")
+        self._adb_auth_password = opts.get("adb_auth_password")
+        self._adb_connect_command = opts.get("adb_connect_command")
+        self._adb_forwarder_command = opts.get("adb_forwarder_command")
 
         self._envd_api_url = f"{'http' if self.connection_config.debug else 'https'}://{self.get_host(self.envd_port)}"
-        self._envd_version = opts["envd_version"]
-        self._envd_access_token = opts["envd_access_token"]
+        self._envd_version = opts.get("envd_version")
+        self._envd_access_token = opts.get("envd_access_token")
 
         # 根据 sandbox id 进行区分 commands 类型
         if "brd" in self._sandbox_id.lower():
@@ -413,6 +422,7 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
         domain: Optional[str] = None,
         debug: Optional[bool] = None,
         proxy: Optional[ProxyTypes] = None,
+        request_timeout: Optional[float] = 10,
     ):
         """
         Connect to an existing sandbox.
@@ -450,48 +460,99 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
             proxy=proxy,
         )
 
-        # Get SSH connection details
-        ssh_info = await SandboxApi._get_ssh(
-            sandbox_id=sandbox_id,
-            api_key=api_key,
-            domain=domain,
-            debug=debug,
-            proxy=proxy,
-        )
+        if "brd" in sandbox_id.lower():
+            # Get SSH connection details
+            ssh_info = await SandboxApi._get_ssh(
+                sandbox_id=sandbox_id,
+                api_key=api_key,
+                domain=domain,
+                debug=debug,
+                request_timeout=request_timeout,
+                proxy=proxy,
+            )
 
-        # Parse SSH connection details from the connect command
-        pattern = r'ssh\s+-p\s+(\d+).*?\s+([^@\s]+)@([\w\.-]+)'
-        ssh_match = re.search(pattern, ssh_info.connect_command)
-        if ssh_match:
-            ssh_port = int(ssh_match.group(1))
-            ssh_username = ssh_match.group(2)
-            ssh_host = ssh_match.group(3)
-            ssh_password = ssh_info.auth_password
+            # Parse SSH connection details from the connect command
+            pattern = r'ssh\s+-p\s+(\d+).*?\s+([^@\s]+)@([\w\.-]+)'
+            ssh_match = re.search(pattern, ssh_info.connect_command)
+            if ssh_match:
+                ssh_port = int(ssh_match.group(1))
+                ssh_username = ssh_match.group(2)
+                ssh_host = ssh_match.group(3)
+                ssh_password = ssh_info.auth_password
+            else:
+                raise Exception("Could not parse SSH connection details")
+            # Get adb connection details
+            adb_info = await SandboxApi._get_adb(
+                sandbox_id=sandbox_id,
+                api_key=api_key,
+                domain=domain,
+                debug=debug,
+                proxy=proxy,
+            )
+            return cls(
+                sandbox_id=sandbox_id,
+                envd_version=response.envd_version,
+                envd_access_token=response._envd_access_token,
+                connection_config=connection_config,
+                ssh_host=ssh_host,
+                ssh_port=ssh_port,
+                ssh_username=ssh_username,
+                ssh_password=ssh_password,
+                adb_auth_command=adb_info.adb_auth_command,
+                adb_auth_password=adb_info.auth_password,
+                adb_connect_command=adb_info.connect_command,
+                adb_forwarder_command=adb_info.forwarder_command
+            )
         else:
-            raise Exception("Could not parse SSH connection details")
+            return cls(
+                sandbox_id=sandbox_id,
+                envd_version=response.envd_version,
+                envd_access_token=response._envd_access_token,
+                connection_config=connection_config,
+                commands=cls.commands
+            )
+        # # Get SSH connection details
+        # ssh_info = await SandboxApi._get_ssh(
+        #     sandbox_id=sandbox_id,
+        #     api_key=api_key,
+        #     domain=domain,
+        #     debug=debug,
+        #     proxy=proxy,
+        # )
 
-        # Get adb connection details
-        adb_info = await SandboxApi._get_adb(
-            sandbox_id=sandbox_id,
-            api_key=api_key,
-            domain=domain,
-            debug=debug,
-            proxy=proxy,
-        )
-        return cls(
-            sandbox_id=sandbox_id,
-            connection_config=connection_config,
-            envd_version=response.envd_version,
-            envd_access_token=response._envd_access_token,
-            ssh_host=ssh_host,
-            ssh_port=ssh_port,
-            ssh_username=ssh_username,
-            ssh_password=ssh_password,
-            adb_auth_command=adb_info.adb_auth_command,
-            adb_auth_password=adb_info.auth_password,
-            adb_connect_command=adb_info.connect_command,
-            adb_forwarder_command=adb_info.forwarder_command
-        )
+        # # Parse SSH connection details from the connect command
+        # pattern = r'ssh\s+-p\s+(\d+).*?\s+([^@\s]+)@([\w\.-]+)'
+        # ssh_match = re.search(pattern, ssh_info.connect_command)
+        # if ssh_match:
+        #     ssh_port = int(ssh_match.group(1))
+        #     ssh_username = ssh_match.group(2)
+        #     ssh_host = ssh_match.group(3)
+        #     ssh_password = ssh_info.auth_password
+        # else:
+        #     raise Exception("Could not parse SSH connection details")
+
+        # # Get adb connection details
+        # adb_info = await SandboxApi._get_adb(
+        #     sandbox_id=sandbox_id,
+        #     api_key=api_key,
+        #     domain=domain,
+        #     debug=debug,
+        #     proxy=proxy,
+        # )
+        # return cls(
+        #     sandbox_id=sandbox_id,
+        #     connection_config=connection_config,
+        #     envd_version=response.envd_version,
+        #     envd_access_token=response._envd_access_token,
+        #     ssh_host=ssh_host,
+        #     ssh_port=ssh_port,
+        #     ssh_username=ssh_username,
+        #     ssh_password=ssh_password,
+        #     adb_auth_command=adb_info.adb_auth_command,
+        #     adb_auth_password=adb_info.auth_password,
+        #     adb_connect_command=adb_info.connect_command,
+        #     adb_forwarder_command=adb_info.forwarder_command
+        # )
 
     async def __aenter__(self):
         return self
@@ -611,6 +672,107 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
             **config_dict,
         )
 
+    @classmethod
+    async def resume(
+        cls,
+        sandbox_id: str,
+        timeout: Optional[int] = None,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+    ):
+        """
+        Resume the sandbox.
+
+        The **default sandbox timeout of 300 seconds** will be used for the resumed sandbox.
+        If you pass a custom timeout via the `timeout` parameter, it will be used instead.
+
+        :param sandbox_id: sandbox ID
+        :param timeout: Timeout for the sandbox in **seconds**
+        :param api_key: E2B API Key to use for authentication
+        :param domain: Domain of the sandbox server
+        :param debug: Enable debug mode
+        :param request_timeout: Timeout for the request in **seconds**
+
+        :return: A running sandbox instance
+        """
+
+        timeout = timeout or cls.default_sandbox_timeout
+
+        await SandboxApi._cls_resume(
+            sandbox_id=sandbox_id,
+            request_timeout=request_timeout,
+            timeout=timeout,
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+        )
+
+        return await cls.connect(
+            sandbox_id=sandbox_id,
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+        )
+
+    @overload
+    async def pause(
+        self,
+        request_timeout: Optional[float] = None,
+    ) -> str:
+        """
+        Pause the sandbox.
+
+        :param request_timeout: Timeout for the request in **seconds**
+
+        :return: sandbox ID that can be used to resume the sandbox
+        """
+        ...
+
+    @overload
+    @staticmethod
+    async def pause(
+        sandbox_id: str,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+    ) -> str:
+        """
+        Pause the sandbox specified by sandbox ID.
+
+        :param sandbox_id: Sandbox ID
+        :param api_key: E2B API Key to use for authentication, defaults to `E2B_API_KEY` environment variable
+        :param request_timeout: Timeout for the request in **seconds**
+
+        :return: sandbox ID that can be used to resume the sandbox
+        """
+        ...
+
+    @class_method_variant("_cls_pause")
+    async def pause(  # type: ignore
+        self,
+        request_timeout: Optional[float] = None,
+    ) -> str:
+        """
+        Pause the sandbox.
+
+        :param request_timeout: Timeout for the request in **seconds**
+
+        :return: sandbox ID that can be used to resume the sandbox
+        """
+
+        await SandboxApi._cls_pause(
+            sandbox_id=self.sandbox_id,
+            api_key=self.connection_config.api_key,
+            domain=self.connection_config.domain,
+            debug=self.connection_config.debug,
+            request_timeout=request_timeout,
+        )
+
+        return self.sandbox_id
+
     async def get_info(  # type: ignore
         self,
         request_timeout: Optional[float] = None,
