@@ -270,7 +270,7 @@ class AgentBoxFilesystem:
 
         try:
             res = self._rpc.list_dir(
-                filesystem_pb2.ListDirRequest(path=path, depth=depth),
+                filesystem_pb2.AgentBoxListDirRequest(path=path, depth=depth),
                 request_timeout=self._connection_config.get_request_timeout(
                     request_timeout
                 ),
@@ -307,7 +307,7 @@ class AgentBoxFilesystem:
         """
         try:
             self._rpc.stat(
-                filesystem_pb2.StatRequest(path=path),
+                filesystem_pb2.AgentBoxStatRequest(path=path),
                 request_timeout=self._connection_config.get_request_timeout(
                     request_timeout
                 ),
@@ -336,7 +336,7 @@ class AgentBoxFilesystem:
         """
         try:
             self._rpc.remove(
-                filesystem_pb2.RemoveRequest(path=path),
+                filesystem_pb2.AgentBoxRemoveRequest(path=path),
                 request_timeout=self._connection_config.get_request_timeout(
                     request_timeout
                 ),
@@ -364,7 +364,7 @@ class AgentBoxFilesystem:
         """
         try:
             r = self._rpc.move(
-                filesystem_pb2.MoveRequest(
+                filesystem_pb2.AgentBoxMoveRequest(
                     source=old_path,
                     destination=new_path,
                 ),
@@ -399,7 +399,7 @@ class AgentBoxFilesystem:
         """
         try:
             self._rpc.make_dir(
-                filesystem_pb2.MakeDirRequest(path=path),
+                filesystem_pb2.AgentBoxMakeDirRequest(path=path),
                 request_timeout=self._connection_config.get_request_timeout(
                     request_timeout
                 ),
@@ -442,7 +442,7 @@ class AgentBoxFilesystem:
 
         try:
             r = self._rpc.create_watcher(
-                filesystem_pb2.CreateWatcherRequest(path=path, recursive=recursive),
+                filesystem_pb2.AgentBoxCreateWatcherRequest(path=path, recursive=recursive),
                 request_timeout=self._connection_config.get_request_timeout(
                     request_timeout
                 ),
